import { LockOutlined, UserOutlined, LoginOutlined } from "@ant-design/icons";
import { message, Row, Col, Button } from "antd";
import React, { useState, useRef } from "react";
import {
  ProFormText,
  LoginForm
} from "@ant-design/pro-form";
import { history, useModel } from "umi";
import { fakeAccountLogin } from "@/services/login";
import styles from "./index.less";
import AES from "crypto-js/aes";
import ECB from "crypto-js/mode-ecb";
import Pkcs7 from "crypto-js/pad-pkcs7";
import Utf8 from "crypto-js/enc-utf8";
import moment from "moment";
import Footer from "@/components/Footer";

let col = { xs: 0, sm: 0, md: 7, lg: 6, xl: 6, xxl: 6 },
  cols = { xs: 24, sm: 24, md: 17, lg: 18, xl: 18, xxl: 18 };

const Login = () => {
  const formRef = useRef();
  const { initialState, setInitialState } = useModel("@@initialState");
  const fetchUserInfo = async () => {
    const userInfo = await initialState?.fetchUserInfo(),
      menuData = await initialState?.getmenuData();
    if (userInfo) {
      localStorage.setItem("WMS_ID", userInfo?.data?.id);
      await setInitialState((s) => {
        return { ...s, routes: {}, currentUser: userInfo?.data, routesMenu: menuData?.userHavePermList, buttonPerm: menuData?.buttonPerm };
      });
    }
  };

  //登录
  const handleLogin = async (values) => {
    let timestamp = moment().valueOf().toString() + "acb";
    let newtimestamp = AES.encrypt(timestamp, Utf8.parse("NANGAODEAESKEY--"), {
      mode: ECB,
      padding: Pkcs7,
    }).toString();
    let password = AES.encrypt(values.password, Utf8.parse(timestamp), {
      mode: ECB,
      padding: Pkcs7,
    }).toString();
    const postdata = {
      accountName: values.userName,
      password: password,
      encryptKey: newtimestamp,
    };
    const res = await fakeAccountLogin({ ...postdata });
    if (res.code === "0000") {
      let token = res?.data?.token;
      localStorage.setItem("TAIANTOKEN", token);
      await fetchUserInfo();
      message.success("🎉 🎉 🎉  登录成功！");
      history.push("/");
      return;
    }
  };

  const handleSubmit = async (values) => {
    await handleLogin(values);
  };

  return (
    <Row className={styles.container}>
      <Col {...col}>
        <div
          className={styles.img}
          style={{
            backgroundImage: `url(${require("@/assets/loginbg.jpg")})`,
            position: "relative",
          }}
        >
          <div className={styles.cover}>
            <img alt="logo" src={require("@/assets/logo_white.png")} />
          </div>
        </div>
      </Col>
      <Col
        {...cols}
      >
        <div
          className='logincontent'
          style={{
            width: "100%",
            height: "100%",
            display: "flex",
            flexDirection: "column",
            justifyContent: 'center'
          }}
        >
          <div className={styles.content}>
            <LoginForm
              submitter={{
                render: (props) => {
                  return (
                    <Button
                      {...props}
                      style={{ width: "100%" }}
                      type="primary"
                      size="large"
                      icon={<LoginOutlined />}
                      onClick={async () => {
                        let values = await formRef.current.validateFields();
                        await handleSubmit(values);
                      }}
                    >
                      登录
                    </Button>
                  );
                },
              }}
              onValuesChange={async (values) => {
                if (Object.keys(values)[0] == "factoryIdList") {
                  formRef.current.setFieldsValue({ storeIdList: [] });
                }
              }}
              title={<span style={{ color: "#fff" }}>WMS</span>}
              subTitle={
                <span style={{ color: "rgba(255,255,255,0.6)" }}>
                  智慧仓储管理系统
                </span>
              }
              initialValues={{
                autoLogin: true,
              }}
              onFinish={async (values) => {
                await handleSubmit(values);
              }}
              style={{
                width: 328,
                marginLeft: 0,
              }} //样式适配
              formRef={formRef}
            >
              <ProFormText
                name="userName"
                fieldProps={{
                  size: "large",
                  prefix: (
                    <UserOutlined className={styles.prefixIcon} />
                  ),
                }}
                placeholder="用户名"
                rules={[
                  {
                    required: true,
                    message: "请输入用户名!",
                  },
                ]}
              />
              <ProFormText.Password
                name="password"
                fieldProps={{
                  size: "large",
                  prefix: (
                    <LockOutlined className={styles.prefixIcon} />
                  ),
                }}
                placeholder="密码"
                rules={[
                  {
                    required: true,
                    message: "请输入密码！",
                  },
                ]}
              />
            </LoginForm>
          </div>
          <Footer></Footer>
        </div>
      </Col>
    </Row>
  );
};

export default Login;
